showComlexObject function

void showComlexObject()

Implementation

void showComlexObject(){
  SingleSelection<ModelTest>(
    //custom style for hint
      boxDecoration: SelectionBoxDecoration(
          hintStyle: const TextStyle(color: Colors.red)),
      //the title of your selection box
      title: 'Select one number',
      //hint text that shows in selection box
      hint: 'choose',
      //when user choose this item will be shown in hint text. it must be string
      showItemSelection: (item) => item.title,
      // these are the items that will be shown in modal
      itemBuilder: (item) => Text(item.title),
      //selection callback
      selectCallBack: (itemSelected) {},
      //your items
      items:getTestModel);
}